@@ -1,21 +1,21 @@
 /*
- *	libetm-0.4 / win32_specific.c - Copyright (C) Emmanuel Thomas-Maurin 2008-2012
+ *	libetm / win32_specific.c - Copyright (C) Emmanuel Thomas-Maurin 2008-2020
  *	<manutm007@gmail.com>
  *
  *	- Win32 specific functions -
  *
- * 	This program is free software: you can redistribute it and/or modify
- * 	it under the terms of the GNU General Public License as published by
- * 	the Free Software Foundation, either version 3 of the License, or
- * 	(at your option) any later version.
+ *	This program is free software: you can redistribute it and/or modify
+ *	it under the terms of the GNU General Public License as published by
+ *	the Free Software Foundation, either version 3 of the License, or
+ *	(at your option) any later version.
  *
- * 	This program is distributed in the hope that it will be useful,
- * 	but WITHOUT ANY WARRANTY; without even the implied warranty of
- * 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * 	GNU General Public License for more details.
+ *	This program is distributed in the hope that it will be useful,
+ *	but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *	GNU General Public License for more details.
  *
- * 	You should have received a copy of the GNU General Public License
- * 	along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *	You should have received a copy of the GNU General Public License
+ *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef WIN32_V
@@ -31,6 +31,36 @@
 
 #define APP_WIN32REG_KEYPATH	"app_win32_registry_keypath"	/* Or whatever */
 
+FILE *std_out, *std_err;
+
+/*
+ * On Linux, STD_OUT = stdout and STD_ERR = stderr / on win32, we must
+ * first create specific text files then pass them to this function.
+ */
+void libetm_init_win32_stdout_stderr(FILE *std_out2, FILE *std_err2)
+{
+	std_out = std_out2;
+	std_err = std_err2;
+}
+
+void libetm_init_win32_sockets()
+{
+	WSADATA		wsadata;
+	int		i;
+
+	if ((i = WSAStartup(MAKEWORD(2, 2), &wsadata)) != 0)
+		big_error/*_in_lib*/(WIN32_ERROR, "WSAStartup() error ", itoa2(i));
+	else if (LOBYTE(wsadata.wVersion) != 2 || HIBYTE(wsadata.wVersion) != 2) {
+		WSACleanup();
+		big_error/*_in_lib*/(WIN32_ERROR, "Couldn't find a usable version of Winsock.dll");
+	}
+}
+
+void libetm_cleanup_win32_sockets()
+{
+	WSACleanup();
+}
+
 /* Return NULL if error */
 const char *get_appdata_dir()
 {
@@ -171,8 +201,22 @@ int get_win32_taskbar_height()
 	return -1;
 }
 
-/* Find up to 15 mac addresses for this computer
- * Return NULL if error */
+/* Unused so commented out */
+/*zboolean is_vista_or_higher()
+{
+	OSVERSIONINFO os_v_info;
+
+	memset(&os_v_info, 0, sizeof(OSVERSIONINFO));
+	os_v_info.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
+	GetVersionEx(&os_v_info);
+	return (os_v_info.dwMajorVersion >= 6 ? TRUE : FALSE);	// Vista = 6.0
+}*/
+
+/* Unused so commented out */
+/*
+ * Find up to 15 mac addresses for this computer
+ * Return NULL if error
+ */
 /*const char **find_mac_addresses()
 {
 	IP_ADAPTER_INFO		*adapter_info;
@@ -210,4 +254,21 @@ int get_win32_taskbar_height()
 	}
 	return (const char **)p_macaddr;
 }*/
+
+const char *win32_error_msg(int i)
+{
+	static char	str[N_SIMULTANEOUS_CALLS][1024];
+	LPVOID		msg_buf;
+	static int	count = -1;
+
+	count++;
+	count &= N_SIMULTANEOUS_CALLS_MASK;
+
+	FormatMessage(FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM |
+		FORMAT_MESSAGE_IGNORE_INSERTS, NULL, (DWORD)i, MAKELANGID(LANG_NEUTRAL,
+		SUBLANG_DEFAULT), (LPTSTR)&msg_buf, 0, NULL);
+	str_n_cpy(str[count], (const char *)msg_buf, 1023);
+	LocalFree(msg_buf);
+	return (const char *)str[count];
+}
 #endif
