@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2020
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2021
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -21,8 +21,8 @@
 
 #define APP_NAME		"Tickr"
 #define APP_CMD			"tickr"
-#define APP_V_NUM		"0.7.0"
-#define COPYRIGHT_STR		"Copyright (C) 2009-2020 Emmanuel Thomas-Maurin"
+#define APP_V_NUM		"0.7.1"
+#define COPYRIGHT_STR		"Copyright (C) 2009-2021 Emmanuel Thomas-Maurin"
 #define WEBSITE_URL		"https://www.open-tickr.net"
 #define DOWNLOAD_URL		WEBSITE_URL "/download.php"
 #define SUPPORT_URL		WEBSITE_URL "/help.php"
@@ -156,7 +156,7 @@
 #define ARBITRARY_TASKBAR_HEIGHT 25		/* Could/should be get from window manager ? */
 
 /*
- * File names, paths and dirs stuff
+ * === File names, paths and dirs stuff ===
  *
  * Linux version:	/usr/bin/
  *			/usr/share/APP_CMD/
@@ -199,7 +199,9 @@
 #define TICKR_LOGO		APP_CMD "-logo.png"
 #define RSS_ICON		APP_CMD "-rss-icon.png"
 
-/* Default config values */
+/*
+ * Default config values
+ */
 #define DELAY			8
 #define SHIFTSIZE		1
 #ifndef G_OS_WIN32
@@ -263,6 +265,7 @@
 #define CLOCKSEC		'n'
 #define CLOCK12H		'y'
 #define CLOCKDATE		'n'
+#define CLOCKALTDATEFORM	'n'
 #define CFONTNAME		FONTNAME
 #define CFONTSIZE		FONTSIZE
 #define CFGCOLOR		FGCOLOR
@@ -353,7 +356,9 @@ typedef enum {
 } next_action;
 
 /* typedef struct's */
-/* Useful graphical (and other) ticker 'environment' values */
+/*
+ * === Useful graphical (and other) ticker 'environment' values ===
+ */
 typedef struct {
 	GdkScreen	*screen;			/* GDK screen for win */
 	GdkVisual	*visual;
@@ -389,6 +394,9 @@ typedef struct {
 	char		GUUI[FILE_NAME_MAXLEN + 1];*/
 } FeedLinkAndOffset;
 
+/*
+ * === Resource is the current feed/file being fetched, processed and displayed ===
+ */
 typedef struct {
 	_resrc_type	type;					/* URL (including local URL) or text file */
 	char		id[FILE_NAME_MAXLEN + 1];		/* URL (including local URL) or full path/file name */
@@ -490,6 +498,7 @@ typedef struct {
 	char		clock_sec;
 	char		clock_12h;
 	char		clock_date;
+	char		clock_alt_date_form;	/* Use alternative date format, ie "Mon 01 Jan" instead of "Mon Jan 01" */
 	char		clock_font_name_size[FONT_MAXLEN + 1];
 	GdkColor	clock_fg_color;
 	guint16		clock_fg_color_alpha;
@@ -517,7 +526,7 @@ typedef struct {
 	int		send_recv_timeout;
 } Params;
 
-/* Headers files for most source files are below */
+/* Prototypes for most source files are below */
 /* tickr_main.c */
 TickerEnv	*get_ticker_env();
 Resource	*get_resource();
@@ -600,6 +609,7 @@ char		*log2vis_utf8(const char *);
 
 /* tickr_feedpicker.c */
 void		highlight_and_go_to_row(GtkTreeView *, GtkTreeSelection *, int);
+int		check_and_update_feed_url(char *, char *);
 void		manage_list_and_selection(Resource *);
 
 /* tickr_prefwin.c */
@@ -646,7 +656,7 @@ void		export_opml_file();
 /* tickr_http.c */
 void		remove_chunk_info(char **);
 int		connect_with_url(sockt *, char *);
-int		fetch_resource(const char *, const char *, char *);
+int		fetch_resource(char *, const char *, char *);
 const char	*build_http_request(const char *, const char *, const char *,
 			const char *);
 int 		get_http_response(sockt, const char *, const char *, const char *,
