@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2020
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2021
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -25,7 +25,8 @@
 #else
 #  define NO_PADDING		"#"			/* (win32) Remove leading zeros (if any) */
 #endif
-#define DATE_STR		"%a %b %" NO_PADDING "d  "
+#define DATE_STR		"%a %b %" NO_PADDING "d  "	/* Mon Jan 01 */
+#define DATE_STR_2		"%a %" NO_PADDING "d %b  "	/* Mon 01 Jan */
 
 /*
  *	R -> " | 00:00:00 AM"
@@ -44,6 +45,7 @@ void display_time(const Params *prm)
 	float			shadow_k;
 	time_t			time2;
 	char			*format;
+	char			*date_str;
 	char			time_str[64];
 	char			tmp[64];
 	int			height_diff;
@@ -60,43 +62,31 @@ void display_time(const Params *prm)
 	pango_layout_set_font_description(p_layout, f_des);
 	pango_font_description_free(f_des);
 
-	/*if (prm->clock_date == 'y') {
-		if (prm->clock_sec == 'y') {
-			if (prm->clock_12h == 'y')
-				format = DATE_STR "%-I:%M:%S %p";
-			else
-				format = DATE_STR "%-H:%M:%S";
-		} else {
-			if (prm->clock_12h == 'y')
-				format = DATE_STR "%-I:%M %p";
-			else
-				format = DATE_STR "%-H:%M";
-		}
-	} else {
-		if (prm->clock_sec == 'y') {
-			if (prm->clock_12h == 'y')
-				format = "%-I:%M:%S %p";
-			else
-				format = "%-H:%M:%S";
-		} else {
-			if (prm->clock_12h == 'y')
-				format = "%-I:%M %p";
-			else
-				format = "%-H:%M";
-		}
-	}*/
-
 	if (prm->clock_date == 'y') {
 		if (prm->clock_sec == 'y') {
-			if (prm->clock_12h == 'y')
-				format = DATE_STR "%" NO_PADDING "I:%M:%S %p";
-			else
-				format = DATE_STR "%" NO_PADDING "H:%M:%S";
+			if (prm->clock_12h == 'y') {
+				if (prm->clock_alt_date_form != 'y')
+					format = DATE_STR "%" NO_PADDING "I:%M:%S %p";
+				else
+					format = DATE_STR_2 "%" NO_PADDING "I:%M:%S %p";
+			} else {
+				if (prm->clock_alt_date_form != 'y')
+					format = DATE_STR "%" NO_PADDING "H:%M:%S";
+				else
+					format = DATE_STR_2 "%" NO_PADDING "H:%M:%S";
+			}
 		} else {
-			if (prm->clock_12h == 'y')
-				format = DATE_STR "%" NO_PADDING "I:%M %p";
-			else
-				format = DATE_STR "%" NO_PADDING "H:%M";
+			if (prm->clock_12h == 'y') {
+				if (prm->clock_alt_date_form != 'y')
+					format = DATE_STR "%" NO_PADDING "I:%M %p";
+				else
+					format = DATE_STR_2 "%" NO_PADDING "I:%M %p";
+			} else {
+				if (prm->clock_alt_date_form != 'y')
+					format = DATE_STR "%" NO_PADDING "H:%M";
+				else
+					format = DATE_STR_2 "%" NO_PADDING "H:%M";
+			}
 		}
 	} else {
 		if (prm->clock_sec == 'y') {
@@ -279,7 +269,7 @@ int get_clock_width(const Params *prm)
 		local_time = localtime(&time2);
 
 		if (prm->clock_date == 'y') {
-			strftime(tmp, 64, DATE_STR, local_time);
+			strftime(tmp, 64, DATE_STR, local_time);	/* Will have same width using DATE_STR or DATE_STR_2 */
 			pango_layout_set_text(p_layout, tmp, -1);
 			pango_layout_context_changed(p_layout);
 			pango_layout_get_pixel_size(p_layout, &layout_width, &layout_height);
@@ -345,6 +335,6 @@ int get_clock_width(const Params *prm)
 				g_object_unref(p_layout);
 		}
 	} else
-		width = 0;	/* Return 0 although if clock = none, actual widget width = 1. */
+		width = 0;	/* Return 0 although if clock = none, actual widget width = 1 */
 	return width;
 }
