@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2020
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2021
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -69,7 +69,7 @@ int get_feed(Resource *resrc, const Params *prm)
 	str_n_cpy(file_name, get_datafile_full_name_from_name(RESOURCE_DUMP), FILE_NAME_MAXLEN);
 
 	/* We replace resrc->id with modified URL, file_name = downloaded resource. */
-	if ((error_code = fetch_resource((const char *)resrc->id, (const char *)file_name, url)) == OK) {
+	if ((error_code = fetch_resource(resrc->id, (const char *)file_name, url)) == OK) {
 		VERBOSE_INFO_OUT("Resource fetched: %s\n", (const char *)resrc->id);
 	} else if (error_code == FEED_FORMAT_ERROR || error_code == RESOURCE_ENCODING_ERROR) {
 		warning(M_S_MOD, "%s: %s", global_error_str(error_code), resrc->id);
@@ -409,8 +409,7 @@ static const char *try_str_to_utf8(const char *str)
 }
 
 /*
- * Info is 1 int + 4 strings, 255 chars long each.
- * feed_* can be NULL.
+ * Info is 1 int + 4 strings, feed_* can be NULL.
  */
 int get_feed_info(int *format, const char *file_name, char *feed_title, char *feed_link, char *feed_ttl)
 {
