@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2020
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2021
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -44,9 +44,10 @@ static int tree_selection_changed(GtkTreeSelection *selection)
 		gtk_entry_set_text(GTK_ENTRY(url_entry), url_str);
 		if (get_params()->enable_feed_ordering == 'y')
 			gtk_entry_set_text(GTK_ENTRY(rank_entry), itoa2(atoi(rank_str)));
-		if (IS_FLIST(flist))
+		if (IS_FLIST(flist)) {
 			if ((f_index = f_list_search(flist, url_str)) > -1)
 				flist = f_list_nth(flist, f_index + 1);
+		}
 		g_free(url_str);
 		g_free(rank_str);
 	}
@@ -70,9 +71,10 @@ static int double_click_on_tree_view(GtkTreeView *tree_view, GtkTreePath *tree_p
 		gtk_entry_set_text(GTK_ENTRY(url_entry), url_str);
 		if (get_params()->enable_feed_ordering == 'y')
 			gtk_entry_set_text(GTK_ENTRY(rank_entry), rank_str);
-		if (IS_FLIST(flist))
+		if (IS_FLIST(flist)) {
 			if ((f_index = f_list_search(flist, url_str)) > -1)
 				flist = f_list_nth(flist, f_index + 1);
+		}
 		g_free(url_str);
 		g_free(rank_str);
 	}
@@ -111,15 +113,15 @@ static int checkbox_toggled(GtkCellRendererToggle *renderer, char *path_str, gpo
 			COLUMN_INT, &f_index,
 			COLUMN_BOOLEAN_CHECKED, &checked,
 			-1);
-			checked = !checked;
-			gtk_list_store_set(GTK_LIST_STORE(tree_model), &iter,
-				COLUMN_BOOLEAN_CHECKED, checked,
-				-1);
-			if (IS_FLIST(flist)) {
-				flist2 = f_list_nth(flist, f_index + 1);
-				if (IS_FLIST(flist2))
-					flist2->selected = checked;
-			}
+		checked = !checked;
+		gtk_list_store_set(GTK_LIST_STORE(tree_model), &iter,
+			COLUMN_BOOLEAN_CHECKED, checked,
+			-1);
+		if (IS_FLIST(flist)) {
+			flist2 = f_list_nth(flist, f_index + 1);
+			if (IS_FLIST(flist2))
+				flist2->selected = checked;
+		}
 	}
 	return TRUE;
 }
@@ -132,14 +134,15 @@ static void select_all(GtkTreeView *tree_view)
 
 	tree_model = gtk_tree_view_get_model(tree_view);
 	if (gtk_tree_model_get_iter_first(tree_model, &iter)) {
-		do
+		do {
 			gtk_list_store_set(GTK_LIST_STORE(tree_model), &iter,
 				COLUMN_BOOLEAN_CHECKED, TRUE,
 				-1);
-		while (gtk_tree_model_iter_next(tree_model, &iter));
-		if (IS_FLIST(flist))
+		} while (gtk_tree_model_iter_next(tree_model, &iter));
+		if (IS_FLIST(flist)) {
 			for (flist2 = f_list_first(flist); IS_FLIST(flist2); flist2 = flist2->next)
 				flist2->selected = TRUE;
+		}
 	}
 }
 
@@ -151,14 +154,15 @@ static void unselect_all(GtkTreeView *tree_view)
 
 	tree_model = gtk_tree_view_get_model(tree_view);
 	if (gtk_tree_model_get_iter_first(tree_model, &iter)) {
-		do
+		do {
 			gtk_list_store_set(GTK_LIST_STORE(tree_model), &iter,
 				COLUMN_BOOLEAN_CHECKED, FALSE,
 				-1);
-		while (gtk_tree_model_iter_next(tree_model, &iter));
-		if (IS_FLIST(flist))
+		} while (gtk_tree_model_iter_next(tree_model, &iter));
+		if (IS_FLIST(flist)) {
 			for (flist2 = f_list_first(flist); IS_FLIST(flist2); flist2 = flist2->next)
 				flist2->selected = FALSE;
+		}
 	}
 }
 
@@ -173,14 +177,15 @@ static void clear_ranking(GtkTreeView *tree_view)
 	str_n_cpy(rank, BLANK_STR_16, FLIST_RANK_STR_LEN);
 	/*snprintf(rank, FLIST_RANK_STR_LEN + 1, FLIST_RANK_FORMAT, 0);*/
 	if (gtk_tree_model_get_iter_first(tree_model, &iter)) {
-		do
+		do {
 			gtk_list_store_set(GTK_LIST_STORE(tree_model), &iter,
 				COLUMN_STRING_RANK, rank,
 				-1);
-		while (gtk_tree_model_iter_next(tree_model, &iter));
-		if (IS_FLIST(flist))
+		} while (gtk_tree_model_iter_next(tree_model, &iter));
+		if (IS_FLIST(flist)) {
 			for (flist2 = f_list_first(flist); IS_FLIST(flist2); flist2 = flist2->next)
 				str_n_cpy(flist2->rank, rank, FLIST_RANK_STR_LEN);
+		}
 	}
 }
 
@@ -213,7 +218,7 @@ static void fill_list_store_from_flnode(GtkListStore *list_store)
 	int		i = 0;
 
 	gtk_list_store_clear(list_store);
-	if (IS_FLIST(flist))
+	if (IS_FLIST(flist)) {
 		for (flist2 = f_list_first(flist); IS_FLIST(flist2); flist2 = flist2->next) {
 			gtk_list_store_append(list_store, &iter);
 			gtk_list_store_set(list_store, &iter,
@@ -225,46 +230,74 @@ static void fill_list_store_from_flnode(GtkListStore *list_store)
 				-1);
 			i++;
 		}
+	}
 }
 
-/* Use url_entry and rank_entry (global vars in this src file) */
+/*
+ * Check if URL is valid  and reacheable, and update it if so
+ * feed_url max len = FILE_NAME_MAXLEN
+ * feed_title max len = FEED_TITLE_MAXLEN
+ * feed_title can be NULL
+ */
+int check_and_update_feed_url(char *feed_url, char *feed_title)
+{
+	char	*unesc_str;
+	int	unused;
+
+	unesc_str = g_uri_unescape_string((const char *)feed_url, NULL);
+	if (unesc_str != NULL) {
+		str_n_cpy(feed_url, unesc_str, FILE_NAME_MAXLEN);
+		g_free(unesc_str);
+	} else {
+		DEBUG_INFO("URL is not valid\n")
+		return RESOURCE_INVALID;
+	}
+	/* URL updated for moved-permanently redirects */
+	if (fetch_resource(feed_url, get_datafile_full_name_from_name(TMP_FILE), feed_url) == OK) {
+		get_feed_info(&unused, get_datafile_full_name_from_name(TMP_FILE), feed_title, NULL, NULL);
+		g_unlink(get_datafile_full_name_from_name(TMP_FILE));
+		return OK;
+	} else {
+		DEBUG_INFO("URL is unreachable or invalid\n")
+		return RESOURCE_NOT_FOUND;
+	}
+}
+
+/*
+ * Use url_entry and rank_entry (global vars in this src file)
+ * Update resrc (eventually)
+ */
 static int add_feed_to_flnode_and_list_store(Resource *resrc, GtkListStore *list_store)
 {
-	FList	*flist2;
-	int	rss_status;
-	char	rss_feed_title[FEED_TITLE_MAXLEN + 1];
-	char	rss_feed_link[FILE_NAME_MAXLEN + 1];
-	char	rss_feed_ttl[32];
+	char	feed_url[FILE_NAME_MAXLEN + 1];
+	char	feed_title[FEED_TITLE_MAXLEN + 1];
 	char	rank[FLIST_RANK_STR_LEN + 1];
-	int	unused;
-	char	resrc_id_bak[FILE_NAME_MAXLEN + 1];
+	FList	*flist2;
+	int	check_status;
 
-	str_n_cpy(resrc_id_bak, resrc->id, FILE_NAME_MAXLEN);
-	str_n_cpy(resrc->id, (char *)gtk_entry_get_text(GTK_ENTRY(url_entry)), FILE_NAME_MAXLEN);
-	if ((rss_status = get_feed(resrc, get_params())) == OK) {
+	str_n_cpy(feed_url, (char *)gtk_entry_get_text(GTK_ENTRY(url_entry)), FILE_NAME_MAXLEN);
+
+	if ((check_status = check_and_update_feed_url(feed_url, feed_title)) == OK) {
+		str_n_cpy(resrc->id, feed_url, FILE_NAME_MAXLEN);
 		if (get_params()->enable_feed_ordering != 'y') {
 			if (IS_FLIST(flist) && (flist2 = f_list_nth(flist, f_list_search(flist, resrc->id) + 1)) != NULL)
 				str_n_cpy(rank, flist2->rank, FLIST_RANK_STR_LEN);
 			else
 				str_n_cpy(rank, BLANK_STR_16, FLIST_RANK_STR_LEN);
-		} else
+		} else {
 			str_n_cpy(rank, (char *)gtk_entry_get_text(GTK_ENTRY(rank_entry)), FLIST_RANK_STR_LEN);
+		}
 		/* Fix LP bug #1272129 */
 		if (IS_FLIST(flist))
 			flist = f_list_last(flist);
-		/* If valid, added URL is set selected */
-		if (get_feed_info(&unused, resrc->id, rss_feed_title, rss_feed_link, rss_feed_ttl) == OK)
-			flist = f_list_add_at_end(flist, resrc->id, rss_feed_title, rss_status == OK ? TRUE : FALSE, rank);
-		else
-			flist = f_list_add_at_end(flist, resrc->id, "", rss_status == OK ? TRUE : FALSE, rank);
+		/* Added URL is set selected */
+		flist = f_list_add_at_end(flist, feed_url, feed_title, TRUE, rank);
 		flist = f_list_sort(flist);
 		fill_list_store_from_flnode(list_store);
 	} else {
-		/* === TODO: Find out how to handle an invalid or unreachable URL === */
-		warning(BLOCK, "URL is invalid or unreachable (or whatever)");
-		return RESOURCE_INVALID;
+		warning(BLOCK, "URL is unreachable or invalid (or whatever)");
 	}
-	return rss_status;
+	return check_status;
 }
 
 /*
@@ -333,7 +366,8 @@ void manage_list_and_selection(Resource *resrc)
 	gtk_widget_set_tooltip_text(selection_but, tooltip_text);
 	l_str_free(tooltip_text);
 
-	cancel_but = cancel_but;	/* To get rid of some annoying compiler warnings */
+	/* To get rid of these boring compiler warnings */
+	cancel_but = cancel_but;
 	selectall_but = selectall_but;
 	unselectall_but = unselectall_but;
 	clear_ranking_but = clear_ranking_but;
@@ -344,7 +378,8 @@ void manage_list_and_selection(Resource *resrc)
 	add_but = add_but;
 	single_but = single_but;
 	selection_but = selection_but;
-	clear_but = clear_but;		/* Until here */
+	clear_but = clear_but;
+	/* (Until here) */
 
 	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER_ALWAYS);
@@ -366,8 +401,9 @@ void manage_list_and_selection(Resource *resrc)
 		flist = f_list_sort(flist);
 		fill_list_store_from_flnode(list_store);
 		flist_bak = f_list_clone(flist);
-	} else
+	} else {
 		flist = NULL;
+	}
 	set_feed_list(flist);
 
 	tree_view = GTK_TREE_VIEW(gtk_tree_view_new_with_model(GTK_TREE_MODEL(list_store)));
@@ -408,10 +444,11 @@ void manage_list_and_selection(Resource *resrc)
 	g_signal_connect(G_OBJECT(renderer1), "toggled", G_CALLBACK(checkbox_toggled), tree_view);
 
 	hbox = gtk_hbox_new(FALSE, 0);
-	if (get_params()->enable_feed_ordering != 'y')
-		tmp_label = gtk_label_new("<b>New Feed</b>  ->  Enter URL:");	/* or <span foreground=\"red\"></span>, <big></big>, ... */
-	else
+	if (get_params()->enable_feed_ordering != 'y') {
+		tmp_label = gtk_label_new("<b>New Feed</b>  ->  Enter URL:");	/* Or <span foreground=\"red\"></span>, <big></big>, ... */
+	} else {
 		tmp_label = gtk_label_new("<b>New Feed</b>  ->  Enter rank and URL:");
+	}
 	gtk_label_set_use_markup(GTK_LABEL(tmp_label), TRUE);
 	gtk_box_pack_start(GTK_BOX(hbox), tmp_label, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new("  "), TRUE, FALSE, 0);
@@ -423,10 +460,11 @@ void manage_list_and_selection(Resource *resrc)
 	}
 	url_entry = gtk_entry_new();
 	gtk_entry_set_max_length(GTK_ENTRY(url_entry), FILE_NAME_MAXLEN);
-	if (get_params()->enable_feed_ordering != 'y')
+	if (get_params()->enable_feed_ordering != 'y') {
 		gtk_entry_set_width_chars(GTK_ENTRY(url_entry), URL_ENTRY_LENGTH);
-	else
-		gtk_entry_set_width_chars(GTK_ENTRY(url_entry), URL_ENTRY_LENGTH - 10);	/* about ... */
+	} else {
+		gtk_entry_set_width_chars(GTK_ENTRY(url_entry), URL_ENTRY_LENGTH - 10);		/* About ... */
+	}
 	gtk_box_pack_start(GTK_BOX(hbox), url_entry, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), clear_but, FALSE, FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
@@ -444,14 +482,11 @@ void manage_list_and_selection(Resource *resrc)
 	/* Backup last valid opened resource (if any) */
 	str_n_cpy(resrc_id_bak, resrc->id, FILE_NAME_MAXLEN);
 	if (IS_FLIST(flist) && resrc->id[0] != '\0') {
-		if ((f_index = f_list_search(flist, resrc->id)) > -1)
+		if ((f_index = f_list_search(flist, resrc->id)) > -1) {
 			highlight_and_go_to_row(tree_view, selection, f_index + 1);
-		/*
-		 * Try original URL in case of HTTP redirects
-		 * TODO: Find best practice - should new URL replace original URL ?
-		 */
-		else if ((f_index = f_list_search(flist, resrc->orig_url)) > -1)
+		}else if ((f_index = f_list_search(flist, resrc->orig_url)) > -1) {	/* Try original URL in case of HTTP redirects */
 			highlight_and_go_to_row(tree_view, selection, f_index + 1);
+		}
 	}
 	gtk_widget_grab_focus(GTK_WIDGET(tree_view));
 
@@ -470,15 +505,13 @@ void manage_list_and_selection(Resource *resrc)
 		} else if (response == GTK_RESPONSE_CURRENT) {
 			gtk_entry_set_text(GTK_ENTRY(url_entry), (const char *)resrc->id);
 			if (IS_FLIST(flist)) {
-				if ((f_index = f_list_search(flist,
-						gtk_entry_get_text(GTK_ENTRY(url_entry)))) > -1)
+				if ((f_index = f_list_search(flist, gtk_entry_get_text(GTK_ENTRY(url_entry)))) > -1)
 					highlight_and_go_to_row(tree_view, selection, f_index + 1);
 			}
 		} else if (response == GTK_RESPONSE_HOME) {
 			gtk_entry_set_text(GTK_ENTRY(url_entry), (const char *)home_feed);
 			if (IS_FLIST(flist)) {
-				if ((f_index = f_list_search(flist,
-						gtk_entry_get_text(GTK_ENTRY(url_entry)))) > -1)
+				if ((f_index = f_list_search(flist, gtk_entry_get_text(GTK_ENTRY(url_entry)))) > -1)
 					highlight_and_go_to_row(tree_view, selection, f_index + 1);
 			}
 		} else if (response == GTK_RESPONSE_REMOVE) {
@@ -487,15 +520,21 @@ void manage_list_and_selection(Resource *resrc)
 						question_win("Remove highlighted URL from list ?", NO) == YES) {
 					gtk_list_store_remove(list_store, &iter);
 					flist = f_list_remove(flist);
-					if (f_list_count(flist) > 0)
+					if (f_list_count(flist) > 0) {
 						set_feed_list(f_list_first(flist));
-					else
+					} else {
 						set_feed_list(NULL);
+					}
 					f_index = -1;
 					gtk_entry_set_text(GTK_ENTRY(url_entry), "");
 				}
-			} else
+			} else if (! IS_FLIST(flist)) {
+				set_feed_list(flist_bak);
+				fill_list_store_from_flnode(list_store);
+				continue;
+			} else if (f_index < 0) {
 				warning(BLOCK, "You must select an URL first");
+			}
 		} else if (response == GTK_RESPONSE_ADD_UPD) {
 			if (get_params()->enable_feed_ordering == 'y') {
 				if (!(str_is_num(gtk_entry_get_text(GTK_ENTRY(rank_entry))) &&
@@ -506,23 +545,16 @@ void manage_list_and_selection(Resource *resrc)
 					continue;
 				}
 			}
-			if (gtk_entry_get_text(GTK_ENTRY(url_entry))[0] != '\0') {	// FIXME: Some issues here
+			if (gtk_entry_get_text(GTK_ENTRY(url_entry))[0] != '\0') {
 				cursor_position = gtk_editable_get_position(GTK_EDITABLE(url_entry));
 				str_n_cpy(resrc->id, gtk_entry_get_text(GTK_ENTRY(url_entry)), FILE_NAME_MAXLEN);
 				if (add_feed_to_flnode_and_list_store(resrc, list_store) == OK) {
-					if ((f_index = f_list_search(flist,
-							gtk_entry_get_text(GTK_ENTRY(url_entry)))) > -1)
+					if ((f_index = f_list_search(flist, gtk_entry_get_text(GTK_ENTRY(url_entry)))) > -1)
 						highlight_and_go_to_row(tree_view, selection, f_index + 1);
 					/* Backup last valid opened resource (if any) */
 					str_n_cpy(resrc_id_bak, resrc->id, FILE_NAME_MAXLEN);
 				} else {
-					/* === TODO: Find out how to handle an invalid or unreachable URL === */
-					/* Restore last valid opened resource (if any) */
-					/*str_n_cpy(resrc->id, resrc_id_bak, FILE_NAME_MAXLEN);
-					gtk_widget_grab_focus(GTK_WIDGET(url_entry));
-					gtk_editable_set_position(GTK_EDITABLE(url_entry), cursor_position);
-					continue;*/
-					break;
+					continue;
 				}
 			} else {
 				warning(BLOCK, "You must enter an URL first");
@@ -538,18 +570,17 @@ void manage_list_and_selection(Resource *resrc)
 					env->reload_rq = TRUE;
 					break;
 				} else {
-					/* === TODO: Find out how to handle an invalid or unreachable URL === */
-					/* Restore last valid opened resource (if any) */
-					/*str_n_cpy(resrc->id, resrc_id_bak, FILE_NAME_MAXLEN);*/
 					break;
 				}
-			} else
+			} else {
 				warning(BLOCK, "You must enter or select an URL first");
+			}
 		} else if (response == GTK_RESPONSE_SELECTION) {
 			if (IS_FLIST(flist)) {
-				for (flist2 = f_list_first(flist); IS_FLIST(flist2); flist2 = flist2->next)
+				for (flist2 = f_list_first(flist); IS_FLIST(flist2); flist2 = flist2->next) {
 					if (flist2->selected)
 						break;
+				}
 				if (IS_FLIST(flist2)) {
 					if (flist2->selected) {
 						env->selection_mode = MULTIPLE;
@@ -558,8 +589,9 @@ void manage_list_and_selection(Resource *resrc)
 					}
 				}
 				warning(BLOCK, "Selection is empty");
-			} else
+			} else {
 				warning(BLOCK, "URL list is empty");
+			}
 		}
 		gtk_widget_grab_focus(GTK_WIDGET(tree_view));
 	}
@@ -576,10 +608,11 @@ void manage_list_and_selection(Resource *resrc)
 				 * Multiple selection mode: start reading selection with highlighted feed
 				 * - more exactly URL in entry (if any) / first one otherwise
 				 */
-				if ((f_index = f_list_search(get_feed_selection(), gtk_entry_get_text(GTK_ENTRY(url_entry)))) > -1)
+				if ((f_index = f_list_search(get_feed_selection(), gtk_entry_get_text(GTK_ENTRY(url_entry)))) > -1) {
 					set_feed_selection(f_list_nth(get_feed_selection(), f_index + 1));
-				else
+				} else {
 					first_feed();
+				}
 			}
 			if (IS_FLIST(flist_bak))
 				f_list_free_all(flist_bak);
