@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2020
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2021
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -26,16 +26,20 @@ static const char *help_str0[] = {
 	"- You can import feed subscriptions with 'File > Import Feed List (OPML)',\n",
 	"  for instance your Google Reader subscriptions.\n\n",
 
+	"- To add a new feed, open 'File > Feed Organizer (RSS/Atom)', then look\n",
+	"  for 'New Feed -> Enter URL' at the bottom of the window, click 'Clear'\n",
+	"  and type or paste the feed URL.\n\n",
+
 	"- To open a link in your browser, left-click on text.\n\n",
 
 	"- Use mouse wheel to either adjust " APP_NAME " scrolling speed or open the\n",
-	"  'Selected Feed Picker' window to quickly move between selected feeds (use\n",
-	"  <ctrl> + mouse wheel for alternative action.) This behaviour is set in\n",
-	"  the 'Preferences' window as 'Mouse Wheel acts on'.\n\n",
+	"  'Selected Feed Picker' window to quickly move between selected feeds\n",
+	"  (use <ctrl> + mouse wheel for alternative action.) This behaviour is\n",
+	"  set in the 'Preferences' window as 'Mouse Wheel acts on'.\n\n",
 
-	"- Basically, you will use 'File > Feed Organizer (RSS|Atom)' to manage your\n",
-	"  feed list, select feeds, subscribe to new ones, and 'Edit > Preferences'\n",
-	"  to tweak " APP_NAME " appearance as well as other settings.\n\n",
+	"- Basically, use 'File > Feed Organizer (RSS|Atom)' to manage your feed\n",
+	"  list, select feeds, subscribe to new ones, and 'Edit > Preferences'\n",
+	"  to tweak " APP_NAME " appearance and behaviour.\n\n",
 
 	"- 'Window - always on top' -> check this if you want " APP_NAME " to always stay\n",
 	"  above your browser (and any other windows.)\n\n",
@@ -177,6 +181,8 @@ static const char *help_str1[] = {
 	"        clocksec=[y/n]                 Show seconds\n\n",
 	"        clock12h=[y/n]                 12h time format\n\n",
 	"        clockdate=[y/n]                Show date\n\n",
+	"        clockaltdateform=[y/n]         Use alternative date format, ie\n"
+	"                                       'Mon 01 Jan' instead of 'Mon Jan 01'\n\n",
 	"        clockfontname='str'            Clock font name\n\n",
 	"        clockfontsize=n                Clock font size (can't be > " APP_NAME "\n",
 	"                                       height)\n\n",
@@ -212,10 +218,16 @@ static const char *help_str1[] = {
 	"        To open the main menu, right-click inside " APP_NAME " area.\n\n",
 	"        You can import feed subscriptions from another feed reader with\n",
 	"        'File > Import Feed List (OPML)'.\n\n",
+	"        To add a new feed, open 'File > Feed Organizer (RSS/Atom)', then look\n",
+	"        for 'New Feed -> Enter URL' at the bottom of the window, click 'Clear'\n",
+	"        and type or paste the feed URL.\n\n",
 	"        To open a link in your browser, left-click on text.\n\n",
 	"        Use mouse wheel to either adjust " APP_NAME " scrolling speed or open the\n",
 	"        'Selected Feed Picker' window to quickly move between selected feeds\n",
 	"        (use <ctrl> + mouse wheel for alternative action.)\n\n",
+	"        Basically, use 'File > Feed Organizer (RSS|Atom)' to manage your feed\n",
+	"        list, select feeds, subscribe to new ones, and 'Edit > Preferences'\n",
+	"        to tweak " APP_NAME " appearance and behaviour.\n\n",
 	"Local resources:\n",
 	"        file:///path/file_name is considered an URL and will be XML-parsed, ie\n",
 	"        a RSS or Atom format is expected.\n\n",
