@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2020
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2021
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -101,6 +101,7 @@ static int format_quick_check(char *response, int *shift)
 }
 
 /*
+ * Try to connect and set TCP socket.
  * Get host (and port if specified) from URL but if connecting through proxy.
  * Supported schemes are 'http', 'https' and 'file'.
  */
@@ -168,12 +169,21 @@ int connect_with_url(sockt *sock, char *url)
 	}
 }
 
-/*
- * Here, resrc_id will be replaced by modified URL and remote resource
- * will be downloaded and saved under file_name.
+/* === TODO: Better document this func, still a bit confusing ===
+ *
+ * Do fetch resource specified by its id
+ *
+ * resrc_id = URL (including local URL) or full path/file name
+ *
+ * Here, resrc_id will be replaced by modified URL (in case of HTTP
+ * moved-permanently redirects) and remote resource will be downloaded
+ * and saved under file_name.
+ *
+ * === What about url ? ===
+ *
  * Max length of resrc_id, file_name, and url = FILE_NAME_MAXLEN.
  */
-int fetch_resource(const char *resrc_id, const char *file_name, char *url)
+int fetch_resource(char *resrc_id, const char *file_name, char *url)
 {
 	sockt		sock;
 	int		status, recv_status;
@@ -191,6 +201,7 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 	char		*tmp = NULL;
 	int		i, j;
 
+	/* We first check the scheme */
 	if (strncmp(resrc_id, "file://", strlen("file://")) == 0) {
 		/* 'file' scheme */
 		str_n_cpy(url, resrc_id + strlen("file://"), FILE_NAME_MAXLEN - strlen("file://"));
@@ -234,6 +245,7 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 	} else
 		/* 'http' or 'https' scheme */
 		str_n_cpy(url, resrc_id, FILE_NAME_MAXLEN);
+	/* Connecting */
 	if ((i = connect_with_url(&sock, url)) == OK) {
 		if ((status = get_http_response(sock, "GET", "", url, &new_url,
 				&response, &recv_status)) == TCP_SEND_ERROR || status == TCP_RECV_ERROR ||
@@ -338,7 +350,7 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 					get_resource()->orig_url, url)
 				DEBUG_INFO("status = %s\n", global_error_str(status))
 				if (http_moved_permamently)
-					str_n_cpy((char *)resrc_id, url, FILE_NAME_MAXLEN);
+					str_n_cpy(resrc_id, url, FILE_NAME_MAXLEN);
 				continue;
 			} else {
 				warning(M_S_MOD, "%s:\nToo many HTTP redirects", resrc_id);
@@ -467,7 +479,7 @@ const char *build_http_request(const char *method, const char *path,
 		"User-Agent: " APP_NAME "-" APP_V_NUM "\r\n"
 		/* Seems totally useless -
 		 * "Accept-Charset: utf-8\r\n"*/
-		"%s\r\n",		/* optional extra header field(s) */
+		"%s\r\n",		/* Optional extra header field(s) */
 		method, path, host, rq_str);
 	return (const char *)str;
 }
