@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2020
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2021
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -150,10 +150,7 @@ static void easily_modify_params0()
 
 	START_PAUSE_TICKER_WHILE_OPENING
 	if (!no_ui) {
-		if ((i = easily_modify_params(prm)) == DO_NEXT_REOPEN) {
-			END_PAUSE_TICKER_WHILE_OPENING
-			easily_modify_params0(prm);
-		} else if (i == DO_NEXT_OPEN_FULL_SETTINGS) {
+		if ((i = easily_modify_params(prm)) == DO_NEXT_OPEN_FULL_SETTINGS) {
 			END_PAUSE_TICKER_WHILE_OPENING
 			modify_params0();
 		} else if (i == DO_NEXT_OPEN_CONN_SETTINGS) {
@@ -170,10 +167,7 @@ static void modify_params0()
 
 	START_PAUSE_TICKER_WHILE_OPENING
 	if (!no_ui) {
-		if ((i = modify_params(prm)) == DO_NEXT_REOPEN) {
-			END_PAUSE_TICKER_WHILE_OPENING
-			modify_params0(prm);
-		} else if (i == DO_NEXT_OPEN_CONN_SETTINGS) {
+		if ((i = modify_params(prm)) == DO_NEXT_OPEN_CONN_SETTINGS) {
 			END_PAUSE_TICKER_WHILE_OPENING
 			connection_settings0();
 		}
@@ -1266,12 +1260,15 @@ static void welcome_at_first_run()
 		info_win("Welcome !",
 			"  === Welcome to " APP_NAME " v" APP_V_NUM " ! ===\n\n"
 			"- To open the main menu, right-click inside " APP_NAME " area.\n\n"
-			"- To open a link in your browser, left-click on text.\n\n"
 			"- You can import feed subscriptions with 'File > Import Feed List (OPML)',\n"
 			"  for instance your Google Reader subscriptions.\n\n"
-			"- Basically, you will use 'File > Feed Organizer (RSS|Atom)' to manage your\n"
-			"  feed list, select feeds, subscribe to new ones, and 'Edit > Preferences'\n"
-			"  to tweak " APP_NAME " appearance as well as other settings.",
+			"- To add a new feed, open 'File > Feed Organizer (RSS/Atom)', then look\n"
+			"  for 'New Feed -> Enter URL' at the bottom of the window, click 'Clear'\n"
+			"  and type or paste the feed URL.\n\n"
+			"- To open a link in your browser, left-click on text.\n\n"
+			"- Basically, use 'File > Feed Organizer (RSS|Atom)' to manage your feed\n"
+			"  list, select feeds, subscribe to new ones, and 'Edit > Preferences' to\n"
+			"  tweak " APP_NAME " appearance and behaviour.",
 			INFO, FALSE);
 		save_to_config_file(prm);	/* Save config to file so that this win will not appear again */
 	}
@@ -1607,10 +1604,21 @@ int main(int argc, char *argv[])
 			instance_id = 0;
 		}
 	}
+	/* We want "--instance-id=" to be valid too */
+	if (argc >= 2 && strncmp(argv[1], "--instance-id=", strlen("--instance-id=")) == 0) {
+		if ((instance_id = atoi(argv[1] + strlen("--instance-id="))) < 1 || instance_id > 99) {
+			INFO_ERR("Instance ID invalid value: %d\n", instance_id)
+			instance_id = 0;
+		}
+	}
 	/* no-ui must be the 1st or 2nd arg to be effective */
 	if ((argc >= 2 && strncmp(argv[1], "-no-ui", strlen("-no-ui")) == 0) ||
 			(argc >= 3 && strncmp(argv[2], "-no-ui", strlen("-no-ui")) == 0))
 		no_ui = TRUE;
+	/* We want "--no-ui" to be valid too */
+	if ((argc >= 2 && strncmp(argv[1], "--no-ui", strlen("--no-ui")) == 0) ||
+			(argc >= 3 && strncmp(argv[2], "--no-ui", strlen("--no-ui")) == 0))
+		no_ui = TRUE;
 	set_tickr_icon_to_dialog(GTK_WINDOW(env->win));
 	/*
 	 * Create rss icon
@@ -1722,8 +1730,7 @@ int main(int argc, char *argv[])
 	/*
 	 * Feed list stuff
 	 */
-	test_convert_local_feed_list();
-	/* It's getting horribly messy from here ... */
+	test_convert_local_feed_list();		/* Still needed ? Probably not but just in case */
 	if ((i = f_list_load_from_file(&feed_list, NULL)) == OK) {
 		feed_list = f_list_sort(feed_list);
 		feed_list = f_list_first(feed_list);
