@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2020
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2021
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -79,6 +79,7 @@ void set_default_options(Params *prm)
 	prm->clock_sec = CLOCKSEC;
 	prm->clock_12h = CLOCK12H;
 	prm->clock_date = CLOCKDATE;
+	prm->clock_alt_date_form = CLOCKALTDATEFORM;
 	get_gdk_color_from_hexstr(CFGCOLOR, &prm->clock_fg_color, &prm->clock_fg_color_alpha);
 	get_gdk_color_from_hexstr(CBGCOLOR, &prm->clock_bg_color, &prm->clock_bg_color_alpha);
 	prm->set_clock_gradient_bg = SETCLOCKGRADIENTBG;
@@ -453,6 +454,12 @@ int get_name_value_from_option(Params *prm, const char *option)
 			error_code = OPTION_VALUE_INVALID;
 		} else
 			prm->clock_date = value[0];
+	} else if (strcmp(name, "clockaltdateform") == 0) {
+		if (strcmp(value, "y") != 0 && strcmp(value, "n") != 0) {
+			INFO_ERR("Invalid value: %s\n", option)
+			error_code = OPTION_VALUE_INVALID;
+		} else
+			prm->clock_alt_date_form = value[0];
 	} else if (strcmp(name, "clockfontname") == 0)
 		str_n_cpy(c_font_name, value, FONT_NAME_MAXLEN);
 	else if (strcmp(name, "clockfontsize") == 0)
@@ -653,6 +660,7 @@ void save_to_config_file(const Params *prm)
 			"-clocksec=%c\n"
 			"-clock12h=%c\n"
 			"-clockdate=%c\n"
+			"-clockaltdateform=%c\n"
 			"-clockfontname=\"%s\"\n"
 			"-clockfontsize=%d\n"
 			"-clockfgcolor=\"%s\"\n"
@@ -722,6 +730,7 @@ void save_to_config_file(const Params *prm)
 			prm->clock_sec,
 			prm->clock_12h,
 			prm->clock_date,
+			prm->clock_alt_date_form,
 			c_font_name,
 			atoi(c_font_size),
 			get_hexstr_from_gdk_color(&prm->clock_fg_color, &prm->clock_fg_color_alpha),
