@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2020
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2021
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -42,6 +42,7 @@ static GtkWidget	*checkbut_windec, *checkbut_spchars, *checkbut_revsc;
 static GtkWidget	*checkbut_feedtitle, *checkbut_itemtitle, *checkbut_itemdes;
 static GtkWidget	*checkbut_striptags, *checkbut_uppercase;
 static GtkWidget	*checkbut_clocksec, *checkbut_clock12h, *checkbut_clockdate;
+static GtkWidget	*checkbut_clockaltdateform;
 static GtkWidget	*checkbut_nopopups, *checkbut_mouseover, *checkbut_noleftclick;
 static GtkWidget	*checkbut_sfpickercloseswhenpointerleaves, *checkbut_feedordering;
 static GtkWidget	*font_but, *clock_font_but;
@@ -186,8 +187,8 @@ static int check_set_sp_chars_widgets(GtkWidget *widget)
 	return TRUE;
 }
 
-GtkLabel *clock_sec_label, *clock_12h_label, *clock_date_label, *clock_font_label, *clock_fg_color_label,
-	*clock_bg_color_label, *setclockgradientbg_label, *clock_bg_color2_label;
+GtkLabel *clock_sec_label, *clock_12h_label, *clock_date_label, *clock_altdateform_label, *clock_font_label,
+	*clock_fg_color_label, *clock_bg_color_label, *setclockgradientbg_label, *clock_bg_color2_label;
 
 static int check_set_clock_widgets(GtkWidget *widget)
 {
@@ -199,6 +200,13 @@ static int check_set_clock_widgets(GtkWidget *widget)
 		gtk_widget_set_sensitive(GTK_WIDGET(checkbut_clock12h), TRUE);
 		gtk_widget_set_sensitive(GTK_WIDGET(clock_date_label), TRUE);
 		gtk_widget_set_sensitive(GTK_WIDGET(checkbut_clockdate), TRUE);
+		if ((zboolean)gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbut_clockdate))) {
+			gtk_widget_set_sensitive(GTK_WIDGET(clock_altdateform_label), TRUE);
+			gtk_widget_set_sensitive(GTK_WIDGET(checkbut_clockaltdateform), TRUE);
+		} else {
+			gtk_widget_set_sensitive(GTK_WIDGET(clock_altdateform_label), FALSE);
+			gtk_widget_set_sensitive(GTK_WIDGET(checkbut_clockaltdateform), FALSE);
+		}
 		gtk_widget_set_sensitive(GTK_WIDGET(clock_font_label), TRUE);
 		gtk_widget_set_sensitive(GTK_WIDGET(clock_font_but), TRUE);
 		gtk_widget_set_sensitive(GTK_WIDGET(clock_fg_color_label), TRUE);
@@ -216,6 +224,8 @@ static int check_set_clock_widgets(GtkWidget *widget)
 		gtk_widget_set_sensitive(GTK_WIDGET(checkbut_clock12h), FALSE);
 		gtk_widget_set_sensitive(GTK_WIDGET(clock_date_label), FALSE);
 		gtk_widget_set_sensitive(GTK_WIDGET(checkbut_clockdate), FALSE);
+		gtk_widget_set_sensitive(GTK_WIDGET(clock_altdateform_label), FALSE);
+		gtk_widget_set_sensitive(GTK_WIDGET(checkbut_clockaltdateform), FALSE);
 		gtk_widget_set_sensitive(GTK_WIDGET(clock_font_label), FALSE);
 		gtk_widget_set_sensitive(GTK_WIDGET(clock_font_but), FALSE);
 		gtk_widget_set_sensitive(GTK_WIDGET(clock_fg_color_label), FALSE);
@@ -311,8 +321,9 @@ next_action easily_modify_params(Params *prm)
 {
 	int		response;
 	zboolean	changes_have_been_made;
-	int		do_next = DO_NEXT_NOTHING, i;
+	int		do_next = DO_NEXT_NOTHING;
 	Params		*prm_bak;
+	int		i;
 
 	env = get_ticker_env();
 	str_n_cpy(current_url, get_resource()->id, FILE_NAME_MAXLEN);
@@ -511,11 +522,11 @@ next_action easily_modify_params(Params *prm)
 		if (response == GTK_RESPONSE_RESET) {
 			if (question_win("Reset *all* settings to default values ?\n"
 					"(Your current settings will be lost)", NO) == YES) {
-				/* OK like that ? */
 				set_default_options(prm);
+				save_to_config_file(prm);
 				current_feed();
-				env->reload_rq = TRUE;
-				do_next = DO_NEXT_REOPEN;
+				env->compute_rq = TRUE;
+				/*do_next = DO_NEXT_REOPEN;	// Not used anymore */
 				break;
 			} else
 				continue;
@@ -524,15 +535,11 @@ next_action easily_modify_params(Params *prm)
 			set_ui_changes_to_params(prm, FALSE);
 		}
 		if (response == GTK_RESPONSE_FULL_SETTINGS) {
-			/* FIXME: What's best to do about ui changes here ???? */
 			do_next = DO_NEXT_OPEN_FULL_SETTINGS;
 			break;
 		} else if (response == GTK_RESPONSE_CONN_SETTINGS) {
-			/* FIXME: What's best to do about ui changes here ???? */
 			if (question_win("Save changes you (eventually) made before leaving ?", -1) == YES)
 				set_ui_changes_to_params(prm, FALSE);
-			/*if (question_win("Unsaved changes will be lost. Continue ?", NO) == NO)
-				continue;	// Means stay in the loop - Don't get confused here ;) */
 			do_next = DO_NEXT_OPEN_CONN_SETTINGS;
 			break;
 		} else if (response == GTK_RESPONSE_APPLY) {	/* Force apply */
@@ -606,8 +613,9 @@ next_action modify_params(Params *prm)
 	char		c[2]= "c";
 	int		response;
 	zboolean	changes_have_been_made;
-	int		do_next = DO_NEXT_NOTHING, i;
-	Params	*prm_bak;
+	int		do_next = DO_NEXT_NOTHING;
+	Params		*prm_bak;
+	int		i;
 
 	env = get_ticker_env();
 	str_n_cpy(current_url, get_resource()->id, FILE_NAME_MAXLEN);
@@ -748,7 +756,7 @@ next_action modify_params(Params *prm)
 	 * win_x
 	 */
 	adj_winx = gtk_adjustment_new(prm->win_x, 0,
-		(prm->disable_screen_limits == 'y' ? WIN_MAX_X : env->screen_w - 20), 1, 5, 0);	/* Magic value '20' found here */
+		(prm->disable_screen_limits == 'y' ? WIN_MAX_X : env->screen_w - 20), 1, 5, 0);		/* Magic value '20' found here */
 	spinbut_winx = gtk_spin_button_new(GTK_ADJUSTMENT(adj_winx), 0.0, 0);
 	table_attach_styled_double_cell(table, "X position", "Pixels", NULL,
 		spinbut_winx, NULL, NULL, COLUMN_1, COLUMN_2, i, COLUMN_1_ALIGN, COLUMN_2_ALIGN);
@@ -891,7 +899,7 @@ next_action modify_params(Params *prm)
 	gtk_entry_set_max_length(GTK_ENTRY(entry_linedel), DELIMITER_MAXLEN);
 	gtk_entry_set_text(GTK_ENTRY(entry_linedel), prm->line_delimiter);
 	table_attach_styled_double_cell(table, "Line delimiter", NULL,
-		"String that will replace every newline occurence",
+		"String that will replace every newline occurrence",
 		entry_linedel, NULL, NULL, COLUMN_1, COLUMN_2, i, COLUMN_1_ALIGN, COLUMN_2_ALIGN);
 	i++;
 	/*
@@ -1159,6 +1167,17 @@ next_action modify_params(Params *prm)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbut_clockdate), FALSE);
 	clock_date_label = table_attach_styled_double_cell(table, "Show date", NULL, NULL,
 		checkbut_clockdate, NULL, NULL, COLUMN_1, COLUMN_2, i, COLUMN_1_ALIGN, COLUMN_2_ALIGN);
+	i++;
+	 /*
+	  * Clock - use alt date format
+	  */
+	checkbut_clockaltdateform = gtk_check_button_new();
+	if (prm->clock_alt_date_form == 'y')
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbut_clockaltdateform), TRUE);
+	else if (prm->clock_alt_date_form == 'n')
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbut_clockaltdateform), FALSE);
+	clock_altdateform_label = table_attach_styled_double_cell(table, "Alt format (Mon Jan 01 -> Mon 01 Jan)", NULL, NULL,
+		checkbut_clockaltdateform, NULL, NULL, COLUMN_1, COLUMN_2, i, COLUMN_1_ALIGN, COLUMN_2_ALIGN);
 	i++;
 	/*
 	 * Clock font
@@ -1292,6 +1311,7 @@ next_action modify_params(Params *prm)
 	g_signal_connect(G_OBJECT(radio_but_clock_1), "clicked", G_CALLBACK(check_set_clock_widgets), NULL);
 	g_signal_connect(G_OBJECT(radio_but_clock_2), "clicked", G_CALLBACK(check_set_clock_widgets), NULL);
 	g_signal_connect(G_OBJECT(radio_but_clock_3), "clicked", G_CALLBACK(check_set_clock_widgets), NULL);
+	g_signal_connect(G_OBJECT(checkbut_clockdate), "clicked", G_CALLBACK(check_set_clock_widgets), NULL);
 	g_signal_connect(G_OBJECT(top_but), "clicked", G_CALLBACK(move_to_top), NULL);
 	g_signal_connect(G_OBJECT(bottom_but), "clicked", G_CALLBACK(move_to_bottom), NULL);
 	g_signal_connect(G_OBJECT(fullwidth_but), "clicked", G_CALLBACK(set_full_width), NULL);
@@ -1318,11 +1338,11 @@ next_action modify_params(Params *prm)
 		if (response == GTK_RESPONSE_RESET) {
 			if (question_win("Reset *all* settings to default values ?\n"
 					"(Your current settings will be lost)", NO) == YES) {
-				/* OK like that ? */
 				set_default_options(prm);
+				save_to_config_file(prm);
 				current_feed();
-				env->reload_rq = TRUE;
-				do_next = DO_NEXT_REOPEN;
+				env->compute_rq = TRUE;
+				/*do_next = DO_NEXT_REOPEN;	// Not used anymore */
 				break;
 			} else
 				continue;
@@ -1330,11 +1350,8 @@ next_action modify_params(Params *prm)
 			set_ui_changes_to_params(prm, TRUE);
 		}
 		if (response == GTK_RESPONSE_CONN_SETTINGS) {
-			/* FIXME: What's best to do about ui changes here ???? */
 			if (question_win("Save changes you (eventually) made before leaving ?", -1) == YES)
 				set_ui_changes_to_params(prm, TRUE);
-			/*if (question_win("Unsaved changes will be lost. Continue ?", NO) == NO)
-				continue;	// Means stay in the loop - Don't get confused here ;) */
 			do_next = DO_NEXT_OPEN_CONN_SETTINGS;
 			break;
 		} else if (response == GTK_RESPONSE_APPLY) {	/* Force apply */
@@ -1419,9 +1436,7 @@ static void set_ui_changes_to_params(Params *prm, zboolean full)
 			prm->disable_screen_limits = 'y';
 		else
 			prm->disable_screen_limits = 'n';
-	}
 
-	if (full) {
 		/* Window x, w */
 		prm->win_x = (int)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinbut_winx));
 		prm->win_w = (int)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinbut_winw));
@@ -1590,6 +1605,12 @@ static void set_ui_changes_to_params(Params *prm, zboolean full)
 		else
 			prm->clock_date = 'n';
 
+		/* Clock - use alt date format */
+		if ((zboolean)gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbut_clockaltdateform)))
+			prm->clock_alt_date_form = 'y';
+		else
+			prm->clock_alt_date_form = 'n';
+
 		str_n_cpy(prm->clock_font_name_size, (char *)gtk_font_button_get_font_name(GTK_FONT_BUTTON(clock_font_but)), FONT_MAXLEN);
 
 		gtk_color_button_get_color(GTK_COLOR_BUTTON(clock_fg_color_but), &prm->clock_fg_color);
