@@ -1,4 +1,5 @@
-/*	(Re)Configure xwin
+/*
+ *	(Re)Configure xwin
  *	Compile with: gcc -o win-config win-config.c -lX11
  */
 
